pybedtools.contrib.plotting.ConfiguredBedToolsDemo
==================================================

.. currentmodule:: pybedtools.contrib.plotting

.. autoclass:: ConfiguredBedToolsDemo

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ConfiguredBedToolsDemo.__init__
      ~ConfiguredBedToolsDemo.plot
   
   

   
   
   